@@ -1,4 +1,4 @@
-
+import pathlib
 
 
 def get_parser(args):
@@ -7,7 +7,7 @@ def get_parser(args):
 
     parser = argparse.ArgumentParser(description='Compute the Ambient Absorption imagery product for lidar')
     parser.add_argument('input',
-                        help='PDAL-readable lidar content')
+                        help='PDAL-readable lidar content', type=pathlib.Path)
     parser.add_argument('--output',
                         help='Output filename', type=str, default='exposure')
     parser.add_argument('--filters',
@@ -22,6 +22,8 @@ def get_parser(args):
                         help='PDAL streaming chunk size', type =int, default=int(1e6))
     parser.add_argument('--blue',
                         help='Use blue shade intensity', default=True)
+    parser.add_argument('--full-output',
+                        help='Output all intermediate output', default=True)
     parser.add_argument('--debug',
                         action='store_true',
                         help='print debug messages to stderr')
